@@ -1,10 +1,9 @@
-from fontTools.misc.py23 import *
+from fontTools.misc.py23 import byteord, tobytes
 from fontTools.feaLib.error import FeatureLibError
 from fontTools.feaLib.location import FeatureLibLocation
 from fontTools.misc.encodingTools import getEncoding
 from collections import OrderedDict
 import itertools
-from typing import NamedTuple
 
 SHIFT = " " * 4
 
@@ -701,7 +700,7 @@ class AttachStatement(Statement):
 
 
 class ChainContextPosStatement(Statement):
-    """A chained contextual positioning statement.
+    r"""A chained contextual positioning statement.
 
     ``prefix``, ``glyphs``, and ``suffix`` should be lists of
     `glyph-containing objects`_ .
@@ -759,7 +758,7 @@ class ChainContextPosStatement(Statement):
 
 
 class ChainContextSubstStatement(Statement):
-    """A chained contextual substitution statement.
+    r"""A chained contextual substitution statement.
 
     ``prefix``, ``glyphs``, and ``suffix`` should be lists of
     `glyph-containing objects`_ .
@@ -1259,9 +1258,15 @@ class MultipleSubstStatement(Statement):
         """Calls the builder object's ``add_multiple_subst`` callback."""
         prefix = [p.glyphSet() for p in self.prefix]
         suffix = [s.glyphSet() for s in self.suffix]
-        builder.add_multiple_subst(
-            self.location, prefix, self.glyph, suffix, self.replacement, self.forceChain
-        )
+        if not self.replacement and hasattr(self.glyph, "glyphSet"):
+            for glyph in self.glyph.glyphSet():
+                builder.add_multiple_subst(
+                    self.location, prefix, glyph, suffix, self.replacement, self.forceChain
+                )
+        else:
+            builder.add_multiple_subst(
+                self.location, prefix, self.glyph, suffix, self.replacement, self.forceChain
+            )
 
     def asFea(self, indent=""):
         res = "sub "
@@ -1669,7 +1674,7 @@ class NameRecord(Statement):
         def escape(c, escape_pattern):
             # Also escape U+0022 QUOTATION MARK and U+005C REVERSE SOLIDUS
             if c >= 0x20 and c <= 0x7E and c not in (0x22, 0x5C):
-                return unichr(c)
+                return chr(c)
             else:
                 return escape_pattern % c
 
